@@ -1,19 +1,7 @@
 /*
  *  Copyright © 2006 Keith Packard <keithp@keithp.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful, but
- *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+ *  SPDX-License-Identifier: GPL-2.0+
  */
 #include <unistd.h>
 #include <sys/stat.h>
@@ -158,10 +146,13 @@ rev_list_file(rev_file *file, analysis_t *out, cvs_master *cm, rev_master *rm)
     yylex_destroy(scanner);
 
     fclose(in);
-    cvs_master_digest(cvs, cm, rm);
-    out->total_revisions = cvs->nversions;
-    out->skew_vulnerable = cvs->skew_vulnerable;
-    out->generator = cvs->gen;
+    if (cvs_master_digest(cvs, cm, rm) == NULL) {
+	warn("warning - master file %s has no revision number - ignore file\n", file->name);
+    } else {
+	out->total_revisions = cvs->nversions;
+	out->skew_vulnerable = cvs->skew_vulnerable;
+	out->generator = cvs->gen;
+    }
     cvs_file_free(cvs);
 }
 
