@@ -1,19 +1,7 @@
 /*
  *  Copyright © 2006 Keith Packard <keithp@keithp.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful, but
- *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+ *  SPDX-License-Identifier: GPL-2.0+
  */
 #include "cvs.h"
 #include <unistd.h>
@@ -255,7 +243,7 @@ main(int argc, char **argv)
 		   " -A --authormap                  Author map file\n"
 		   " -R --revision-map               Revision map file\n"
 		   " -r --reposurgeon                Issue cvs-revision properties\n"
-		   " -T                              Force deteministic dates\n"
+		   " -T                              Force deterministic dates\n"
                    " -e --remote                     Relocate branches to refs/remotes/REMOTE\n"
                    " -s --strip                      Strip the given prefix instead of longest common prefix\n"
 		   " -p --progress                   Enable load-status reporting\n"
