@@ -1,19 +1,7 @@
 /*
  *  Copyright © 2006 Keith Packard <keithp@keithp.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful, but
- *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+ *  SPDX-License-Identifier: GPL-2.0+
  */
 #include "cvs.h"
 #include "revdir.h"
@@ -817,16 +805,17 @@ merge_branches(rev_ref **branches, int nbranch,
 		    dump_number_file(LOGFILE,
 				     REVISIONS(present)->master->name,
 				     REVISIONS(present)->number);
-		warn("\n");
+		fprintf(LOGFILE, "\n");
 		/*
 		 * The file part of the error message could be spurious for
 		 * a multi-file commit, alas.  It wasn't any better back when
 		 * both flavors of commit had dedicated 'file' members; the
 		 * problem is that we can't actually know which CVS file
 		 * commit is the right one for purposes of this message.
+		 * (uniform warn messages jw 20151122)
 		 */
-		fprintf(LOGFILE, "\tbranch(%3d): %s  ",
-			n, cvstime2rfc3339(prev->date));
+		warn("\tbranch(%3d): %s  ", n,
+		    cvstime2rfc3339(prev->date));
 		revdir_iter *ri = revdir_iter_alloc(&prev->revdir);
 		first = revdir_iter_next(ri);
 		free(ri);
